/*
 *	Copyright(c) 2017 by Maciej Więcierzewski
*/

function Slider()
{
    this.slides = [];
    this.hashes = [];
    this.currIndex = 0;
}

Slider.prototype.addSlide = function(slideObj)
{
    this.hashes[slideObj.hash] = this.slides.length;
    this.slides.push(slideObj);
}

Slider.prototype.setIndex = function(hash)
{
	var index = this.hashes[hash];
	
    if(index === undefined)
        return;
	
	this.currIndex = index;
}

// goes to slide by slide name
Slider.prototype.goToSlide = function(hash)
{
    var index = this.hashes[hash];
	
    if(index === undefined)
        return;

    this.goToSlideIndex(index);
}

// the actual sliding function
Slider.prototype.goToSlideIndex = function(index)
{
    var currSlide = this.slides[this.currIndex];
    var nextSlide = this.slides[index];

    var currElem = $('#'+currSlide.id);		// current slide div element
    var nextElem = $('#'+nextSlide.id);		// div element of next slide being displayed

    var width = $('#'+currSlide.id+' .page').get(0).offsetWidth + 100;	// space between slides
    var time = 400;		// animation time
	
	// callback called when animaion is finished.
    var complete = function()
    {
        currElem.css("left", "0px");
        currElem.css("visibility", "hidden");
    }.bind(this);

    // animation
    if(index < this.currIndex)	// sliding to right
    {
        currElem.stop(true, true);
        currElem.css("left", "0px");
        currElem.animate({ opacity: '0.0', left: width+"px" }, time, "linear", complete);

        nextElem.stop(true, true);
        nextElem.css("left", "-"+width+"px" );
        nextElem.css("visibility", "visible");
        nextElem.animate({ opacity: '1.0', left: "0px"  }, time, "linear");
    }
    else if(index > this.currIndex)  // sliding to left
    {
        currElem.stop(true, true);
        currElem.css("left", "0px");
        currElem.animate({ opacity: '0.0', left: "-"+width+"px" }, time, "linear", complete);

        nextElem.stop(true, true);
        nextElem.css("left", width+"px");
        nextElem.css("visibility", "visible");
        nextElem.animate({ opacity: '1.0', left: "0px" }, time), "linear";
    }
    else
    {
        currElem.stop(true, true);
        currElem.animate({ opacity: '0.0' }, 0);
        currElem.animate({ opacity: '1.0' }, 200, function() { this.updateHeight(currSlide.id); }.bind(this));
    }
	
    this.currIndex = index;
	
	this.updateHeight();
}

Slider.prototype.updateHeight = function()
{
	var slideId = this.slides[this.currIndex].id;
    var height = parseInt($('#'+slideId+' .page').get(0).offsetHeight);
    
    setPageHeight(height+500);
}
